@@ -29,14 +29,14 @@
   (define (with-mock-wrapper func)
     (lambda (obj)
       (cond ((mock? obj)
-	     (let-temporarily (((openlets) #f))
+	     (let-temporarily (((*s7* 'openlets) #f))
 	       (func (obj 'value))))
 
 	    ((not (openlet? obj))
 	     (func obj))
 
 	    ((procedure? obj) ; TODO: and c-pointer? c-object?
-	     (let-temporarily (((openlets) #f))
+	     (let-temporarily (((*s7* 'openlets) #f))
 	       (func obj)))
 
 	    (else
@@ -64,12 +64,12 @@
 		  args)
 	(if unknown-openlets
 	    (apply func (reverse new-args))
-	    (let-temporarily (((openlets) #f)) 
+	    (let-temporarily (((*s7* 'openlets) #f)) 
 	      (apply func (reverse new-args)))))))
 
   ;; one tricky thing here is that a mock object can be the let of with-let: (with-let (mock-port ...) ...)
-  ;;   so a mock object's method can be called even when no argument is a mock object.  Even trickier, the
-  ;;   mock object can be a closure's containing (open)let: (display (openlet (with-let (mock-c-pointer 0) (lambda () 1))))
+  ;;   so a mock object's method can be called even when no argument is a mock object.  Even trickier
+  ;;   (display (openlet (with-let (mock-c-pointer 0) (lambda () 1))))
   ;; --------------------------------------------------------------------------------
 
   (set! *mock-vector*
@@ -410,6 +410,7 @@
 		       'char-ci>=?         (with-mock-wrapper* #_char-ci>=?)
 		       'string             (with-mock-wrapper* #_string)
 		       'string-fill!       (with-mock-wrapper* #_string-fill!)
+		       'fill!              (with-mock-wrapper* #_fill!)
 		       'object->string     (with-mock-wrapper* #_object->string)
 		       'format             (with-mock-wrapper* #_format)
 		       'write              (with-mock-wrapper* #_write)
@@ -529,9 +530,10 @@
 		 '<=               (with-mock-wrapper* #_<=)
 		 '>=               (with-mock-wrapper* #_>=)
 		 
-		 'make-polar       (if (provided? 'pure-s7)
-				       (lambda (mag ang) (#_complex (* mag (cos ang)) (* mag (sin ang))))
-				       (lambda args (apply #_make-polar (map ->value args))))
+ 		 'make-polar       (if (provided? 'pure-s7)
+ 				       (lambda (mag ang) (#_complex (* mag (cos ang)) (* mag (sin ang))))
+ 				       (lambda (mag ang) (#_make-polar (->value mag) (->value arg))))
+
 		 'make-rectangular (with-mock-wrapper* #_complex)
 		 'complex          (with-mock-wrapper* #_complex)
 		 'random-state     (with-mock-wrapper* #_random-state)
@@ -558,6 +560,7 @@
 		 'string->list     (with-mock-wrapper* #_string->list)
 		 'substring        (with-mock-wrapper* #_substring)
 		 'vector-fill!     (with-mock-wrapper* #_vector-fill!)
+		 'fill!            (with-mock-wrapper* #_fill!)
 		 'make-string      (with-mock-wrapper* #_make-string)
 		 'string-ref       (with-mock-wrapper* #_string-ref)
 		 'string-set!      (with-mock-wrapper* #_string-set!)
@@ -865,7 +868,8 @@
 	       (mock-symbol-class
 		(inlet 'equivalent?           (with-mock-wrapper* #_equivalent?)
 		       'gensym?               (with-mock-wrapper #_gensym?)
-		       ;'append                (with-mock-wrapper* #_append) ;? (append ... 'a ...) is an error
+		       ;'append               (with-mock-wrapper* #_append) ;? (append ... 'a ...) is an error
+		       'fill!                 (with-mock-wrapper* #_fill!)
 		       'symbol->string        (with-mock-wrapper #_symbol->string)
 		       'symbol->value         (with-mock-wrapper* #_symbol->value)
 		       'symbol->dynamic-value (with-mock-wrapper #_symbol->dynamic-value)
@@ -916,6 +920,7 @@
 		       'format          (with-mock-wrapper* #_format)
 		       'write           (with-mock-wrapper* #_write)
 		       'display         (with-mock-wrapper* #_display)
+		       'fill!           (with-mock-wrapper* #_fill!)
 		       )))
 	  
 	  (define* (mock-c-pointer (int 0) type info weak1 weak2)
@@ -1097,4 +1102,4 @@
   ((p 'owner) p) -> "bil"
 |#
 
-  ) ; end of outer let
+  #f) ; end of outer let
