@@ -1,6 +1,6 @@
 ;;; r7rs compatibility
 
-(require libc.scm stuff.scm)
+(require libc.scm)
 (provide 'r7rs.scm)
 
 
@@ -24,7 +24,7 @@
 (define r7rs-vector-fill! fill!) ; or do these return the sequence, not the filler?
 (define r7rs-string-fill! fill!)
 
-(define* (vector-copy! dest at src (start 0) end) ; apparently end is exclusive here?
+(define* (vector-copy! dest at src (start 0) end) ; end is exclusive
   (let ((len (or end (length src))))
     (if (or (not (eq? dest src))
 	    (<= at start))
@@ -57,15 +57,18 @@
 (define (boolean=? . args)
   (or (null? args)
       (and (boolean? (car args))
-	   (or (null? (cdr args))
-	       (every? (lambda (obj) (eq? (car args) obj)) (cdr args))))))
+	   (let loop ((obj (car args)) (lst (cdr args)))
+	     (or (null? lst)
+		 (and (eq? obj (car lst))
+		      (loop obj (cdr lst))))))))
 
 (define (symbol=? . args) 
   (or (null? args)
       (and (symbol? (car args))
-	   (or (null? (cdr args))
-	       (every? (lambda (obj) (eq? (car args) obj)) (cdr args))))))
-
+	   (let loop ((obj (car args)) (lst (cdr args)))
+	     (or (null? lst)
+		 (and (eq? obj (car lst))
+		      (loop obj (cdr lst))))))))
 
 (define char-foldcase char-downcase) 
 (define string-foldcase string-downcase)
@@ -401,7 +404,7 @@
 (define (machine-name) (caddr ((*libc* 'uname))))
 (define (os-version) (string-append (list-ref ((*libc* 'uname)) 3) " " (list-ref ((*libc* 'uname)) 4)))
 (define (implementation-name) (copy "s7"))
-(define (implementation-version) (substring (s7-version) 3 7))
+(define (implementation-version) (substring (*s7* 'version) 3 7))
 
 ;; command-line is problematic: s7 has no access to the caller's "main" function, and
 ;;   outside Windows, there's no reasonable way to get these arguments.
@@ -462,6 +465,8 @@
 (define-record-type box-type (box value) box? (value unbox set-box!))
 
 #|
+;(require stuff.scm)
+
 ;;; more than r7rs desires I think:
 (define-macro (define-record-type type make ? . fields)
   (let ((new-type (if (pair? type) (car type) type))
