@@ -1,6 +1,5 @@
 ;;; translations from snd-motif.scm
 ;;;
-;;; display-scanned-synthesis
 ;;; zync and unzync
 ;;; disable control panel
 ;;; show-disk-space
@@ -14,6 +13,9 @@
 ;;; make-font-selector-dialog
 ;;; add-main-menu-mnemonics
 
+(unless (provided? 'gtk4)
+  (error 'gtk-error "gtk-effects-utils.scm only works in gtk4"))
+
 (provide 'snd-snd-gtk.scm)
 (require snd-gtk snd-extensions.scm snd-play.scm)
 
@@ -47,295 +49,6 @@
 	       (substring (val 4) 0 (val 3)))))))
   
   
-  
-#|
-;;; -------- display-scanned-synthesis --------
-;;;
-;;; open a new main pane below the listener, with two sections
-;;;  on the left various controls, on the right a graph
-;;;  push 'start' to start the scanned synthesis display
-;;;  if spring > mass, you'll get overflows
-;;;
-  
-  (define scanned-synthesis-pane #f)
-  
-  (define (display-scanned-synthesis)
-    
-    (define vibrating-uniform-circular-string
-      ;; copied from dsp.scm to simplify life
-      (lambda (size x0 x1 x2 mass xspring damp)
-	(define circle-float-vector-ref 
-	  (lambda (v i)
-	    (if (< i 0)
-		(v (+ size i))
-		(if (>= i size)
-		    (v (- i size))
-		    (v i)))))
-	(let* ((dm (/ damp mass))
-	       (km (/ xspring mass))
-	       (denom (+ 1.0 dm))
-	       (p1 (/ (+ 2.0 (- dm (* 2.0 km))) denom))
-	       (p2 (/ km denom))
-	       (p3 (/ -1.0 denom)))
-	  (do ((i 0 (+ i 1)))
-	      ((= i size))
-	    (set! (x0 i) (min (+ (* p1 (x1 i))
-				 (* p2 (+ (circle-float-vector-ref x1 (- i 1)) (circle-float-vector-ref x1 (+ i 1))))
-				 (* p3 (x2 i)))
-			      1000.0)))
-	  (copy x1 x2)
-	  (copy x0 x1))))
-    
-    (set! *clm-srate* 22050.0)
-    
-    (let* ((mass 1.0)
-	   (xspring 0.1)
-	   (damp 0.0)
-	   (bounds ())
-	   (pts1 #f)
-	   (ax0 0) (ax1 0) (ay0 0) (ay1 0)
-	   (gc (car (snd-gcs)))
-	   
-	   ;; now set up a paned window in the main Snd window with controllers on the left and the graph on the right
-	   (scan-outer (let ((pane (gtk_box_new GTK_ORIENTATION_HORIZONTAL 0)))
-			 (gtk_box_pack_start (GTK_BOX ((main-widgets) 5)) pane #f #f 4)
-			 (gtk_widget_show pane)
-			 pane))
-	   (scan-row (let ((box (gtk_box_new GTK_ORIENTATION_VERTICAL 0)))
-		       (gtk_box_pack_start (GTK_BOX scan-outer) box #f #f 0)
-		       (gtk_widget_show box)
-		       box))
-	   ;; the graph
-	   (scan-pane (let ((grf (gtk_drawing_area_new)))
-			(gtk_widget_set_events grf GDK_ALL_EVENTS_MASK)
-			(gtk_box_pack_start (GTK_BOX scan-outer) grf #t #t 0)
-			(gtk_widget_show grf)
-			grf))
-	   ;; the controllers
-	   (scan-start (let ((label (gtk_button_new_with_label "Start")))
-			 (gtk_box_pack_start (GTK_BOX scan-row) label #t #t 0)
-			 (gtk_widget_show label)
-			 label))
-	   (scan-continue (let ((label (gtk_button_new_with_label "Continue")))
-			    (gtk_box_pack_start (GTK_BOX scan-row) label #t #t 0)
-			    (gtk_widget_show label)
-			    label))
-	   (scan-stop (let ((label (gtk_button_new_with_label "Stop")))
-			(gtk_box_pack_start (GTK_BOX scan-row) label #t #t 0)
-			(gtk_widget_show label)
-			label))
-	   (size 128)
-	   (tbl (make-table-lookup :size size))
-	   (amplitude 0.02)
-	   (gx0 (mus-data tbl))
-	   (gx1 (make-float-vector size))	   
-	   (gx2 (make-float-vector size))
-	   (vect (make-vector (* 2 size)))
-	   (work-proc #f)
-	   (play-button #f)) ; fixed up later -- needed in stop-synthesis
-      
-      (define (y->grfy y range)
-	(min ay1
-	     (max ay0
-		  (round (+ ay0
-			    (* range (- 10.0 y)))))))
-      
-      (define (cairo-draw-lines cr data size)
-	(cairo_set_line_width cr 4.0)
-	(cairo_move_to cr (data 0) (data 1))
-	(do ((i 1 (+ i 1))
-	     (j 2 (+ j 2)))
-	    ((= i size))
-	  (cairo_line_to cr (data j) (data (+ j 1))))
-	(cairo_stroke cr))
-      
-      (define (draw-graph cr)
-	(if (and (> ax1 ax0)
-		 (> ay1 ay0))
-	    (let ((diff (* 0.05 (- ay1 ay0))) ; assuming -10 to 10 
-		  (xincr (/ (- ax1 ax0) size))
-		  (bg-color (color->list *basic-color*)))
-	      (cairo_set_source_rgb cr (car bg-color) (cadr bg-color) (caddr bg-color))
-	      (if pts1
-		  (cairo-draw-lines cr pts1 size)
-		  (begin
-		    (cairo_rectangle cr (+ ax0 2) ay0 (- ax1 ax0 2) (- ay1 ay0))
-		    (cairo_fill cr)))
-	      (cairo_set_source_rgb cr 0.0 0.0 0.0)
-	      (cairo_set_line_width cr 1.0)
-	      (let ((x (floor ax0))
-		    (y (y->grfy (gx0 0) diff)))
-		(cairo_move_to cr x y)
-		(set! (vect 0) x)
-		(set! (vect 1) y))
-	      (do ((i 1 (+ i 1))
-		   (j 2 (+ j 2))
-		   (xi (+ ax0 xincr) (+ xi xincr)))
-		  ((= i size))
-		(let ((x (floor xi))
-		      (y (y->grfy (gx0 i) diff)))
-		  (set! (vect j) x)
-		  (set! (vect (+ j 1)) y)
-		  (cairo_line_to cr x y)))
-	      (cairo_stroke cr)
-	      (set! pts1 vect))))
-      
-      (define (redraw-graph)
-	(let* ((wn (GDK_WINDOW (gtk_widget_get_window scan-pane)))
-	       (cr (make_cairo wn)))
-	  (set! bounds (draw-axes scan-pane gc "scanned synthesis" 0.0 1.0 -10.0 10.0 x-axis-in-seconds show-all-axes cr))
-	  (set! ax0 (+ (car bounds) 4))
-	  (set! ax1 (caddr bounds))
-	  (set! ay1 (cadr bounds))
-	  (set! ay0 (cadddr bounds))
-	  (draw-graph cr)
-	  (free_cairo cr)))
-      
-      (define (tick-synthesis n)
-	;; background process
-	(vibrating-uniform-circular-string size gx0 gx1 gx2 mass xspring damp)
-	(let* ((wn (GDK_WINDOW (gtk_widget_get_window scan-pane)))
-	       (cr (make_cairo wn)))
-	  (draw-graph cr)
-	  (free_cairo cr))
-	#t)
-      
-      (define (stop-synthesis)
-	(if work-proc
-	    (g_source_remove work-proc))
-	(set! work-proc #f)
-	(gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON play-button) #f))
-      
-      (define (start-synthesis)
-	(stop-synthesis)
-	(fill! gx0 0.0)
-	(fill! gx1 0.0)
-	(fill! gx2 0.0)
-	(do ((i 0 (+ i 1)))
-	    ((= i 12))
-	  (let ((val (sin (/ (* 2 pi i) 12.0))))
-	    (set! (gx1 (+ i (- (/ size 4) 6))) val)))
-	(set! work-proc (g_idle_add tick-synthesis #f)))
-      
-      (define (continue-synthesis)
-	(stop-synthesis)
-	(set! work-proc (g_idle_add tick-synthesis #f)))
-      
-      ;; controller callbacks
-      (for-each 
-       (lambda (data)
-	 (let* ((title (data 0))
-		(minval (data 1))
-		(maxval (data 2))
-		(curval (data 3))
-		(decimals (data 4))
-		(func (data 5))
-		(adj (gtk_adjustment_new curval minval maxval 1.0 10.0 1.0))
-		(scale (gtk_scale_new GTK_ORIENTATION_HORIZONTAL (GTK_ADJUSTMENT adj)))
-		(label (gtk_label_new title)))
-	   (gtk_scale_set_digits (GTK_SCALE scale) decimals)
-	   (gtk_scale_set_value_pos (GTK_SCALE scale) GTK_POS_TOP)
-	   (gtk_scale_set_draw_value (GTK_SCALE scale) #t)
-	   (gtk_box_pack_start (GTK_BOX scan-row) scale #t #t 0)
-	   (gtk_widget_show scale)
-	   (gtk_box_pack_start (GTK_BOX scan-row) label #t #t 0)
-	   (gtk_widget_show label)
-	   (g_signal_connect adj "value_changed" (lambda (w d) (func (gtk_adjustment_get_value (GTK_ADJUSTMENT adj)))) #f)))
-       (list (list "mass" 1 200 100 2 (lambda (val) (set! mass (/ val 100.0))))
-	     (list "spring" 1 100 10 2 (lambda (val) (set! xspring (/ val 100.0))))
-	     (list "damping" 0 100 0 4 (lambda (val) (set! damp (/ val 10000.0))))))
-      
-      (let ((scan-size (gtk_box_new GTK_ORIENTATION_HORIZONTAL 4)))
-	(gtk_box_pack_start (GTK_BOX scan-row) scan-size #t #t 6)
-	(gtk_widget_show scan-size)
-	(let ((scan-label (gtk_label_new "Size:")))
-	  (gtk_box_pack_start (GTK_BOX scan-size) scan-label #f #f 10)
-	  (gtk_widget_show scan-label)
-	  (let ((scan-text (gtk_entry_new)))
-	    (gtk_box_pack_start (GTK_BOX scan-size) scan-text #t #t 0)
-	    (gtk_widget_show scan-text)
-	    (gtk_entry_set_text (GTK_ENTRY scan-text) (number->string size))
-	    (g_signal_connect scan-text "activate"
-			      (lambda (w d) 
-				(stop-synthesis)
-				(set! size (string->number (gtk_entry_get_text (GTK_ENTRY scan-text))))
-				(set! tbl (make-table-lookup :size size))
-				(set! gx0 (mus-data tbl))
-				(set! gx1 (make-float-vector size))	   
-				(set! gx2 (make-float-vector size))
-				(set! vect (make-vector (* size 2))))
-			      #f))))
-      (set! play-button (gtk_check_button_new_with_label "play"))
-      (gtk_box_pack_start (GTK_BOX scan-row) play-button #f #f 4)
-      (gtk_widget_show play-button)
-      (g_signal_connect play-button "toggled"
-			(lambda (w d) 
-			  (if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON play-button))
-			      (let* ((audio-info (open-play-output 1 22050 #f 128))
-				     (audio-fd (car audio-info))
-				     ;; (outchans (cadr audio-info))
-				     (len (caddr audio-info))
-				     (data (make-float-vector len))
-				     (sdata (make-shared-vector data (list 1 len))))
-				(if (not (= audio-fd -1))
-				    (do ()
-					((not (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON play-button)))
-					 (mus-audio-close audio-fd))
-				      (tick-synthesis work-proc)
-				      (do ((k 0 (+ 1 k)))
-					  ((= k len))
-					(float-vector-set! data k (* amplitude (table-lookup tbl))))
-				      (mus-audio-write audio-fd sdata len))))))
-			#f)
-      (let* ((freq-adj (gtk_adjustment_new 440.0 20.0 1000.0 1.0 10.0 1.0)) ; step incr, page incr page size
-	     (amp-adj (gtk_adjustment_new 0.02 0.0 0.1 .001 .01 .001))
-	     (freq-scale (gtk_scale_new GTK_ORIENTATION_HORIZONTAL (GTK_ADJUSTMENT freq-adj)))
-	     (amp-scale (gtk_scale_new GTK_ORIENTATION_HORIZONTAL (GTK_ADJUSTMENT amp-adj)))
-	     (freq-label (gtk_label_new "frequency"))
-	     (amp-label (gtk_label_new "amplitude")))
-	(gtk_scale_set_digits (GTK_SCALE freq-scale) 1)
-	(gtk_scale_set_digits (GTK_SCALE amp-scale) 3)
-	(gtk_scale_set_value_pos (GTK_SCALE freq-scale) GTK_POS_TOP)
-	(gtk_scale_set_value_pos (GTK_SCALE amp-scale) GTK_POS_TOP)
-	(gtk_scale_set_draw_value (GTK_SCALE freq-scale) #t)
-	(gtk_scale_set_draw_value (GTK_SCALE amp-scale) #t)
-	(gtk_box_pack_start (GTK_BOX scan-row) freq-scale #t #t 0)
-	(gtk_box_pack_start (GTK_BOX scan-row) freq-label #t #t 0)
-	(gtk_box_pack_start (GTK_BOX scan-row) amp-scale #t #t 0)
-	(gtk_box_pack_start (GTK_BOX scan-row) amp-label #t #t 0)
-	(gtk_widget_show freq-scale)
-	(gtk_widget_show amp-scale)
-	(gtk_widget_show freq-label)
-	(gtk_widget_show amp-label)
-	(g_signal_connect freq-adj "value_changed" (lambda (w d) (set! (mus-frequency tbl) (gtk_adjustment_get_value (GTK_ADJUSTMENT freq-adj)))) #f)
-	(g_signal_connect amp-adj "value_changed" (lambda (w d) (set! amplitude (gtk_adjustment_get_value (GTK_ADJUSTMENT amp-adj)))) #f)
-	)
-      
-      (g_signal_connect scan-pane "draw" (lambda (w e d) (redraw-graph)) #f)
-      (g_signal_connect scan-pane "configure_event" (lambda (w e d) (redraw-graph)) #f)
-      (g_signal_connect scan-pane "button_press_event" 
-			(lambda (w e d) 
-			  (let ((button (.button (GDK_EVENT_BUTTON e))))
-			    (if (not work-proc)
-				(if (= button 2)
-				    (continue-synthesis)
-				    (start-synthesis))
-				(stop-synthesis))))
-			#f)
-      (g_signal_connect scan-start "clicked" (lambda (w d) (start-synthesis)) #f)
-      (g_signal_connect scan-continue "clicked" (lambda (w d) (continue-synthesis)) #f)
-      (g_signal_connect scan-stop "clicked" (lambda (w d) (stop-synthesis)) #f)
-      #t))
-  
-  
-  (define (close-scanned-synthesis-pane)
-    (gtk_widget_hide scanned-synthesis-pane))
-  
-|#
-
-  
-  
-  
 ;;; -------- zync and unzync: start or stop y-zoom slider sync --------
 ;;; 
 ;;; (i.e. when one y-zoom-slider changes position, all other channels in the sound change in parallel)
@@ -408,20 +121,20 @@
 ;;; adds a label to the status-area area showing the current free space 
   
   (define show-disk-space
-    (let ((labelled-snds ())
-	  
-	  (kmg (lambda (num)
-		 (cond ((<= num 0)      (copy "disk full!"))
-		       ((<= num 1024)   (format #f "space: ~10DK" num))
-		       ((> num 1048576) (format #f "space: ~6,3FG" (/ num (* 1024.0 1024.0))))
-		       (else            (format #f "space: ~6,3FM" (/ num 1024.0))))))
-	  
-	  (show-label (lambda (data)
-			(if (sound? (car data))
-			    (let ((space (kmg (disk-kspace (file-name (car data))))))
-			      (gtk_label_set_text (GTK_LABEL (cadr data)) space)
-			      (g_timeout_add 10000 show-label data) ; every 10 seconds recheck space
-			      0)))))
+    (letrec ((labelled-snds ())
+	      
+	     (kmg (lambda (num)
+		    (cond ((<= num 0)      (copy "disk full!"))
+			  ((<= num 1024)   (format #f "space: ~10DK" num))
+			  ((> num 1048576) (format #f "space: ~6,3FG" (/ num (* 1024.0 1024.0))))
+			  (else            (format #f "space: ~6,3FM" (/ num 1024.0))))))
+	     
+	     (show-label (lambda (data)
+			   (if (sound? (car data))
+			       (let ((space (kmg (disk-kspace (file-name (car data))))))
+				 (gtk_label_set_text (GTK_LABEL (cadr data)) space)
+				 (g_timeout_add 10000 show-label data) ; every 10 seconds recheck space
+				 0)))))
       (lambda (hook)
 	;; (show-disk-space snd) adds a label to snd's status-area area showing the current free space (for use with after-open-hook)
 	;; (set! (hook-functions after-open-hook) (list (*motif* 'show-disk-space)))
@@ -438,7 +151,7 @@
 		  (snd-error "no sound found for disk space label")
 		  (let* ((name-form ((sound-widgets) 10))
 			 (new-label (gtk_label_new (kmg (disk-kspace (file-name snd))))))
-		    (gtk_box_pack_start (GTK_BOX name-form) new-label #f #f 6)
+		    (gtk_box_pack_start (GTK_BOX name-form) new-label)
 		    (gtk_widget_show new-label)
 		    (set! previous-label (list snd new-label))
 		    (set! labelled-snds (cons previous-label labelled-snds))
@@ -473,62 +186,63 @@
   
   (define snd-clock-icon
     (lambda (snd hour)
-      (let ((cr (make_cairo (GDK_WINDOW (gtk_widget_get_window ((sound-widgets snd) 8))))))
-	(let ((bg (color->list *basic-color*)))
-	  (cairo_set_source_rgb cr (car bg) (cadr bg) (caddr bg)))
-	(cairo_rectangle cr 0 0 16 16) ; icon bg
-	(cairo_fill cr)
-	(cairo_set_source_rgb cr 1.0 1.0 1.0)
-	(cairo_arc cr 8 8 7 0 (* 2 pi))  ; clock face
-	(cairo_fill cr)
-	(cairo_set_line_width cr 2.0)
-	(cairo_set_source_rgb cr 0.0 0.0 0.0)
-	(cairo_move_to cr 8 8)         ; clock hour hand
-	(cairo_line_to cr (+ 8 (* 7 (sin (* hour (/ 3.1416 6.0)))))
-		       (- 8 (* 7 (cos (* hour (/ 3.1416 6.0))))))
-	(cairo_stroke cr)
-	(free_cairo cr))))
-  
-  
-#|  
+      (let ((cr ((sound-widgets snd) 7)))
+	(unless (zero? (car (c-pointer->list cr)))
+	  (cairo_push_group cr)
+	  (let ((bg (color->list *basic-color*)))
+	    (cairo_set_source_rgb cr (car bg) (cadr bg) (caddr bg)))
+	  (cairo_rectangle cr 0 0 16 16) ; icon bg
+	  (cairo_fill cr)
+	  (cairo_set_source_rgb cr 1.0 1.0 1.0)
+	  (cairo_arc cr 8 8 7 0 (* 2 pi))  ; clock face
+	  (cairo_fill cr)
+	  (cairo_set_line_width cr 2.0)
+	  (cairo_set_source_rgb cr 0.0 0.0 0.0)
+	  (cairo_move_to cr 8 8)         ; clock hour hand
+	  (cairo_line_to cr (+ 8 (* 7 (sin (* hour (/ 3.1416 6.0)))))
+			 (- 8 (* 7 (cos (* hour (/ 3.1416 6.0))))))
+	  (cairo_stroke cr)
+	  (cairo_pop_group_to_source cr)
+	  (cairo_paint cr)))))
+
 ;;; this is the happy face progress bar
   
   (define (snd-happy-face snd progress)
-    (let* ((window (GDK_WINDOW (gtk_widget_get_window ((sound-widgets snd) 8))))
-	   (cr (make_cairo window))
-	   (fc (list 1.0 progress 0.0)))
-      (let ((bg (color->list *basic-color*)))
-        ;; overall background
-        (cairo_set_source_rgb cr (car bg) (cadr bg) (caddr bg)))
-      (cairo_rectangle cr 0 0 16 16)
-      (cairo_fill cr)
-      
-      ;; round face
-      (cairo_set_source_rgb cr (car fc) (cadr fc) (caddr fc))
-      (cairo_arc cr 8 8 8 0.0 (* 2 pi))
-      (cairo_fill cr)
-      
-      ;; eyes
-      (cairo_set_source_rgb cr 0.0 0.0 0.0)
-      (cairo_arc cr 5 6 1.5 0 (* 2 pi))
-      (cairo_fill cr)
-      
-      (cairo_arc cr 11 6 1.5 0 (* 2 pi))
-      (cairo_fill cr)
-      
-      ;; mouth
-      (cairo_set_line_width cr 1.0)
-      (if (< progress 0.4)
-	  (cairo_arc cr 8 14 4 (* 17/16 pi) (* -1/16 pi))
-	  (if (< progress 0.7)
-	      (begin
-		(cairo_move_to cr 4 12)
-		(cairo_rel_line_to cr 8 0))
-	      (cairo_arc cr 8 8 5 (* 1/16 pi) (* 15/16 pi))))
-      (cairo_stroke cr)
-      
-      (free_cairo cr)))
-|#
+    (let ((cr ((sound-widgets snd) 7))
+	  (fc (list 1.0 progress 0.0)))
+      (unless (zero? (car (c-pointer->list cr)))
+	(cairo_push_group cr)
+	(let ((bg (color->list *basic-color*)))
+	  ;; overall background
+	  (cairo_set_source_rgb cr (car bg) (cadr bg) (caddr bg)))
+	(cairo_rectangle cr 0 0 16 16)
+	(cairo_fill cr)
+	
+	;; round face
+	(cairo_set_source_rgb cr (car fc) (cadr fc) (caddr fc))
+	(cairo_arc cr 8 8 8 0.0 (* 2 pi))
+	(cairo_fill cr)
+	
+	;; eyes
+	(cairo_set_source_rgb cr 0.0 0.0 0.0)
+	(cairo_arc cr 5 6 1.5 0 (* 2 pi))
+	(cairo_fill cr)
+	
+	(cairo_arc cr 11 6 1.5 0 (* 2 pi))
+	(cairo_fill cr)
+	
+	;; mouth
+	(cairo_set_line_width cr 1.0)
+	(if (< progress 0.4)
+	    (cairo_arc cr 8 14 4 (* 17/16 pi) (* -1/16 pi))
+	    (if (< progress 0.7)
+		(begin
+		  (cairo_move_to cr 4 12)
+		  (cairo_rel_line_to cr 8 0))
+		(cairo_arc cr 8 8 5 (* 1/16 pi) (* 15/16 pi))))
+	(cairo_stroke cr)
+	(cairo_pop_group_to_source cr)
+	(cairo_paint cr))))
   
   
 ;;; -------- bring possibly-obscured dialog to top
@@ -586,15 +300,15 @@
   
   
 #|
+;;; change make_cairo here to grab the cairo_t pointer in the draw func
 ;;; -------- with-level-meters, make-level-meter, display-level
   
   (define (make-level-meter parent width height)
     (let ((frame (gtk_frame_new #f)))
       (gtk_widget_set_size_request frame width height)
-      (gtk_box_pack_start (GTK_BOX parent) frame #t #t 4)
+      (gtk_box_pack_start (GTK_BOX parent) frame)
       (gtk_widget_show frame)
       (let ((meter (gtk_drawing_area_new)))
-	(gtk_widget_set_events meter (logior GDK_EXPOSURE_MASK GDK_STRUCTURE_MASK))
 	(gtk_container_add (GTK_CONTAINER frame) meter)
 	(gtk_widget_show meter)
 	(let ((context (list meter 0.0 1.0 0.0 0.0 width height)))
@@ -714,7 +428,7 @@
 	   (width (floor (/ parent-width n)))
 	   (meters (gtk_box_new GTK_ORIENTATION_HORIZONTAL 4))
 	   (meter-list ()))
-      (gtk_box_pack_start (GTK_BOX parent) meters #f #f 4)
+      (gtk_box_pack_start (GTK_BOX parent) meters)
       (gtk_widget_set_size_request meters width height)
       (gtk_widget_show meters)
       (do ((i 0 (+ i 1)))
@@ -771,7 +485,7 @@
       (gtk_widget_set_name dismiss-button "quit_button"))
       
     (set! variables-notebook (gtk_notebook_new))
-    (gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG variables-dialog))) variables-notebook #t #t 4)
+    (gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG variables-dialog))) variables-notebook)
     (gtk_notebook_set_tab_pos (GTK_NOTEBOOK variables-notebook) GTK_POS_RIGHT)
     (gtk_widget_show variables-notebook)
     (gtk_widget_show variables-dialog)
@@ -797,12 +511,12 @@
 	   (let ((text (gtk_label_new "")))
 	     (let ((hbox (gtk_box_new GTK_ORIENTATION_HORIZONTAL 0)))
 	       (let ((label (gtk_label_new var-label)))
-		 (gtk_box_pack_start (GTK_BOX pane) hbox #f #f 2)
+		 (gtk_box_pack_start (GTK_BOX pane) hbox)
 		 (gtk_widget_show hbox)
-		 (gtk_box_pack_start (GTK_BOX hbox) label #f #f 6)
+		 (gtk_box_pack_start (GTK_BOX hbox) label)
 		 (gtk_widget_set_halign (GTK_WIDGET label) GTK_ALIGN_START)
 		 (gtk_widget_show label))
-	       (gtk_box_pack_start (GTK_BOX hbox) text #t #t 6))
+	       (gtk_box_pack_start (GTK_BOX hbox) text))
 	     (gtk_widget_set_halign (GTK_WIDGET text) GTK_ALIGN_START)
 	     (gtk_widget_show text)
 	     text))
@@ -810,12 +524,12 @@
 	   (let ((label (gtk_label_new var-label))
 		 (hbox (gtk_box_new GTK_ORIENTATION_HORIZONTAL 0))
 		 (scale (gtk_progress_bar_new)))
-	     (gtk_box_pack_start (GTK_BOX pane) hbox #f #f 2)
+	     (gtk_box_pack_start (GTK_BOX pane) hbox)
 	     (gtk_widget_show hbox)
-	     (gtk_box_pack_start (GTK_BOX hbox) label #f #f 6)
+	     (gtk_box_pack_start (GTK_BOX hbox) label)
 	     (gtk_widget_set_halign (GTK_WIDGET label) GTK_ALIGN_START)
 	     (gtk_widget_show label)
-	     (gtk_box_pack_start (GTK_BOX hbox) scale #f #f 6)
+	     (gtk_box_pack_start (GTK_BOX hbox) scale)
 	     (gtk_widget_show scale)
 	     (list scale (car range) (cadr range))))
 	  ((graph)
