@@ -718,17 +718,36 @@ void snd_doit(int argc, char **argv)
 #endif
 
 #if HAVE_SCHEME && (!defined(__sun)) && (!defined(_MSC_VER))
-
   if (!nostdin)
     {
-      s7_load(s7, "repl.scm");
-      if ((listener_prompt(ss)) && (strcmp(listener_prompt(ss), DEFAULT_LISTENER_PROMPT) != 0))
-	s7_eval_c_string(s7, "(set! (*repl* 'prompt)                \
+      if (s7_load(s7, "repl.scm")) /* returns NULL if can't find repl.scm */
+	{
+	  if ((listener_prompt(ss)) && (strcmp(listener_prompt(ss), DEFAULT_LISTENER_PROMPT) != 0))
+	    s7_eval_c_string(s7, "(set! (*repl* 'prompt)                \
                                   (lambda (num)				\
                                     (with-let (sublet (*repl* 'repl-let) :num num)  \
 			              (set! prompt-string (format #f \"(~D)~A\" num *listener-prompt*)) \
 			              (set! prompt-length (length prompt-string)))))");
-      s7_eval_c_string(s7, "((*repl* 'run))");
+	  s7_eval_c_string(s7, "((*repl* 'run))");
+	}
+      else
+	{
+	  while (true)
+	    {
+	      char buffer[512];
+	      fprintf(stdout, "\n> ");
+	      if (!fgets(buffer, 512, stdin)) break;  /* error or ctrl-D */
+	      if (((buffer[0] != '\n') || (strlen(buffer) > 1)))
+		{
+		  char response[1024];
+		  snprintf(response, 1024, "(write %s)", buffer);
+		  s7_eval_c_string(s7, response);
+		}
+	    }
+	  fprintf(stdout, "\n");
+	  if (ferror(stdin))
+	    fprintf(stderr, "read error on stdin\n");
+	}
     }
 #else
   if (!nostdin)
