@@ -860,6 +860,13 @@ int main(int argc, char **argv)
     fprintf(stderr, "s7_c_pointer 0 is not null\n");
   if (s7_c_pointer_type(s7_make_c_pointer_with_type(sc, NULL, s7_nil(sc), s7_f(sc))) != s7_nil(sc))
     fprintf(stderr, "s7_c_pointer_type is not ()\n");
+  {
+    s7_pointer csc;
+    csc = s7_make_c_pointer_with_type(sc, (void *)sc, s7_make_symbol(sc, "s7_scheme*"), s7_f(sc));
+    if (!s7_is_c_pointer_of_type(csc, s7_make_symbol(sc, "s7_scheme*")))
+      fprintf(stderr, "c-pointer type %s != s7_scheme*\n", s7_object_to_c_string(sc, s7_c_pointer_type(csc)));
+    s7_c_pointer_with_type(sc, csc, s7_make_symbol(sc, "s7_scheme*"), "ffitest", __LINE__);
+  }
   if (!s7_is_int_vector(s7_make_int_vector(sc, 3, 1, NULL)))
     fprintf(stderr, "s7_make_int_vector did not make an int-vector\n");
   if (s7_is_float_vector(s7_make_int_vector(sc, 3, 1, NULL)))
