@@ -251,4 +251,7 @@
 ;(format *stderr* "~NC lg ~NC~%" 20 #\- 20 #\-)
 ;(system "./repl lg.scm")
 
+(format *stderr* "~NC full s7test ~NC~%" 20 #\- 20 #\-)
+(system "./repl full-s7test.scm")
+
 (exit)
